## Python User Print Utilities

> **pip install userprint**

---

> **import userprint as up**

>   + textMatrix(A):

>   + textMatrixWithTitle(A, title=""):

>   + textVector(A):

>   + textVectorWithIndex(A, label="", id=0):

>   + textIndent(text, indent=0):

>   + textItem(key, value, width=12, precision=5):

